@@ -183,7 +183,6 @@ from sphinx.builders.latex import LaTeXBuilder
 from sphinx.domains import Domain
 from sphinx.environment import BuildEnvironment
 from sphinx.locale import __
-from sphinx.util import progress_message
 from sphinx.util.docutils import SphinxDirective, SphinxFileOutput
 from sphinx.util.nodes import process_only_nodes
 from sphinx.writers.latex import LaTeXTranslator, LaTeXWriter
@@ -191,6 +190,13 @@ from sphinx.writers.latex import LaTeXTranslator, LaTeXWriter
 # this package
 from sphinx_toolbox.utils import Config, SphinxExtMetadata, metadata_add_version
 
+try:
+	# 3rd party
+	from sphinx.util.display import progress_message  # type: ignore[import]
+except ImportError:
+	# 3rd party
+	from sphinx.util import progress_message
+
 _ = BuildEnvironment
 
 __all__ = (
@@ -550,7 +556,12 @@ class PatchedLaTeXBuilder(LaTeXBuilder):
 			with progress_message(__("processing %s") % targetname):
 				doctree = self.env.get_doctree(docname)
 				process_only_nodes(doctree, self.tags)
-				toctree = next(iter(doctree.traverse(addnodes.toctree)), None)
+
+				if hasattr(doctree, "findall"):
+					toctree = next(doctree.findall(addnodes.toctree), None)  # type: ignore[attr-defined]
+				else:
+					toctree = next(iter(doctree.traverse(addnodes.toctree)), None)
+
 				if toctree and toctree.get("maxdepth") > 0:
 					tocdepth = toctree.get("maxdepth")
 				else:
