@@ -91,9 +91,9 @@ if sys.version_info >= (3, 8):  # pragma: no cover (<py38)
 	from typing import get_origin
 else:  # pragma: no cover (py38+)
 	# 3rd party
-	from typing_inspect import get_origin  # type: ignore
+	from typing_inspect import get_origin  # type: ignore[import]
 
-__all__ = ["GenericBasesClassDocumenter", "setup"]
+__all__ = ("GenericBasesClassDocumenter", "setup")
 
 
 class GenericBasesClassDocumenter(PatchedAutoSummClassDocumenter):
@@ -138,7 +138,7 @@ def _add_generic_bases(documenter: Documenter) -> None:
 	fully_qualified = getattr(documenter.env.config, "generic_bases_fully_qualified", False)
 
 	documenter.add_line('', sourcename)
-	bases = []
+	bases = []  # pylint: disable=W8301
 
 	if (
 			hasattr(documenter.object, "__orig_bases__") and len(documenter.object.__orig_bases__)
@@ -181,7 +181,7 @@ class Example(List[Tuple[str, float, List[str]]]):
 	An example of :mod:`sphinx_toolbox.more_autodoc.generic_bases`.
 	"""
 
-	def __init__(self, iterable=()):  # pragma: no cover
+	def __init__(self, iterable=()):  # pragma: no cover  # noqa: MAN001
 		pass
 
 
@@ -199,5 +199,5 @@ class FinalExample(List[Tuple[str, float, List[str]]]):
 	An example of :mod:`sphinx_toolbox.more_autodoc.generic_bases` decorated with ``@final``.
 	"""
 
-	def __init__(self, iterable=()):  # pragma: no cover
+	def __init__(self, iterable=()):  # pragma: no cover  # noqa: MAN001
 		pass
